@@ -1,11 +1,13 @@
 from __future__ import annotations
 
 import threading
-from typing import Generator
+from collections.abc import Generator
 
 import pytest
 
-from quart import Quart, request, ResponseReturnValue
+from quart import Quart
+from quart import request
+from quart import ResponseReturnValue
 
 
 @pytest.fixture(name="app")
@@ -31,14 +33,14 @@ def _app() -> Quart:
 async def test_sync_request_context(app: Quart) -> None:
     test_client = app.test_client()
     response = await test_client.get("/")
-    assert b"GET" in (await response.get_data())  # type: ignore
+    assert b"GET" in (await response.get_data())
     response = await test_client.post("/")
-    assert b"POST" in (await response.get_data())  # type: ignore
+    assert b"POST" in (await response.get_data())
 
 
 async def test_sync_generator(app: Quart) -> None:
     test_client = app.test_client()
     response = await test_client.get("/gen")
     result = await response.get_data()
-    assert result[-2:] == b"bb"  # type: ignore
+    assert result[-2:] == b"bb"
     assert int(result[:-2]) != threading.current_thread().ident
